@@ -1,13 +1,21 @@
-package Data;
-
-#use Easy::Comm;
-use Comm;
-
-#sub get_task_to_do {};
-#sub anything_for_me {};
-use Data::Dump qw(dump);
+package Text::Editor::Easy::Data;
 
+use warnings;
 use strict;
+
+=head1 NAME
+
+Text::Editor::Easy::Data - Global common data shared by all threads.
+
+=head1 VERSION
+
+Version 0.1
+
+=cut
+
+our $VERSION = '0.1';
+
+use Data::Dump qw(dump);
 use threads;
 use Thread::Queue;
 
@@ -68,98 +76,15 @@ use constant {
     EVAL        => 3,
 };
 
-sub return_self {
-    return $self_global;
-}
-
-sub manage_requests {
-    my ($data_queue) = @_;
-
-    my $self = bless [], 'Data';
-
-    #print "Data a t cr\n";
-    $self->[COUNTER] = 0;    # PAs de redirection de print
-    my $secondary_task_queue = Thread::Queue->new;
-
-    $self_global = $self;    # Mise  jour de la variable 'globale'
-
-    my $secondary_cpt = 0;
-    while ( my ( $what, @param ) = Comm::get_task_to_do() ) {
-        last if ( !defined $what );
-        if ( $what eq 'trace' ) {
-            my @dup_param_1 = @param;
-            $secondary_task_queue->enqueue( join( '~@', @dup_param_1 ) );
-            $secondary_cpt += 1;
-            my $not_finished = 1;
-            while ($not_finished) {
-                while ( Comm::anything_for_me() ) {
-                    ( $what, @param ) = Comm::get_task_to_do();
-                    if ( $what ne 'trace' ) {
-
-                        #print "DATA : $what est plus urgent\n";
-                        execute( $self, $what, @param );
-                    }
-                    else {
-                        my @dup_param_2 = @param;
-                        $secondary_task_queue->enqueue(
-                            join( '~@', @dup_param_2 ) );
-                        $secondary_cpt += 1;
-                    }
-                }
-                if ( $secondary_cpt > 0 ) {
-
-             #print "DATA : traitement de trace, moins urgent $secondary_cpt\n";
-                    $secondary_cpt -= 1;
-                    my @tab = split( /~@/, $secondary_task_queue->dequeue );
-                    execute( $self, 'trace', @tab );
-                }
-                else {
-                    $not_finished = 0;
-                }
-            }
-        }
-        else {
-            execute( $self, $what, @param );
-        }
-    }
-}
-
-my %ref_sub
-  ;  # Stockage des mthodes appeles pour viter l'valuation ds le 2me appel
-
-sub execute {
-    my ( $self, $what, @param ) = @_;
-
-    if ( !$ref_sub{$what} ) {
-        my $ref_sub = eval "\\&$what";
-        my $response;
-        eval {
-            $response = Comm::simple_context_call( $self, $ref_sub, @param );
-        };
-        if ($@) {
-            print STDERR
-"La fonction $what n'est pas correctement implmente dans le package ",
-              __PACKAGE__, " $@\n";
-            print STDERR $@;
-            Comm::respond( @param, undef );
-        }
-        else {
-            Comm::respond( @param, $response );
-            $ref_sub{$what} = $ref_sub;
-        }
-    }
-    else {
-        Comm::simple_call( $self, $ref_sub{$what}, @param );
-    }
-}
-
 sub reference_editor {
     my ( $self, $ref, $zone_ref, $file_name, $name ) = @_;
 
-  #print "Dans reference_editor de Data : $ref, |$zone_ref|$file_name|$name|\n";
+#print DBG "Dans reference_editor de Data : $self |$ref|$zone_ref|$file_name|$name|\n";
     my $zone;
     if ( defined $zone_ref ) {
-        if ( ref $zone_ref eq 'HASH' or ref $zone_ref eq 'Zone' ) {
+        if (   ref $zone_ref eq 'HASH'
+            or ref $zone_ref eq 'Text::Editor::Easy::Zone' )
+        {
             $zone = $zone_ref->{'name'};
         }
         else {
@@ -192,6 +117,10 @@ sub reference_editor {
 sub data_file_name {
     my ( $self, $ref ) = @_;
 
+    print DBG "Dans data_file_name $self|$ref|";
+    my $file_name = $self->[INSTANCE]{$ref}{'file_name'};
+    print DBG "$file_name" if ( defined $file_name );
+    print DBG "|\n";
     return $self->[INSTANCE]{$ref}{'file_name'};
 }
 
@@ -206,7 +135,7 @@ sub data_get_editor_from_name {
 
     my $instance_ref = $self->[INSTANCE];
 
-    #print DAT "Dans data_get...$self|$wanted_name\n";
+    #print DBG "Dans data_get...$self|$wanted_name\n";
     for my $key_ref ( %{$instance_ref} ) {
         my $name = $instance_ref->{$key_ref}{'name'};
         if ( defined $name and $name eq $wanted_name ) {
@@ -223,11 +152,11 @@ sub data_get_editor_from_file_name {
 
     my $instance_ref = $self->[INSTANCE];
 
-    #print DAT "Dans data_get...$self|$wanted_name\n";
+    #print DBG "Dans data_get...$self|$wanted_name\n";
     for my $key_ref ( %{$instance_ref} ) {
         my $name = $instance_ref->{$key_ref}{'file_name'};
 
-        #print DAT "Dans boucle data...$key_ref|$name\n";
+        #print DBG "Dans boucle data...$key_ref|$name\n";
         return $key_ref if ( defined $name and $name eq $wanted_name );
     }
     return;
@@ -279,16 +208,27 @@ sub name_of_zone_order {
     }
 }
 
+sub init_data {
+    my ( $self, $reference, $data_queue ) = @_;
+
+    #print DBG "Dans init_data : $self, $reference, $data_queue\n";
+    bless $self, 'Text::Editor::Easy::Data';
+
+    #print "Data a t cr\n";
+    $self->[COUNTER] = 0;         # PAs de redirection de print
+    $self_global = $self;         # Mise  jour de la variable 'globale'
+}
+
 use IO::File;
 
 my $name       = fileparse($0);
 my $own_STDOUT = "tmp/${name}_trace.trc";
-open( ENC, ">$own_STDOUT" ) or die "ouverture de $own_STDOUT : $!\n";
-autoflush ENC;
+if ( $Text::Editor::Easy::Trace{'trace_print'} ) {
+    open( ENC, ">$own_STDOUT" ) or die "ouverture de $own_STDOUT : $!\n";
+    autoflush ENC;
+}
 
-my $data_trace = "tmp/${name}_Data.trc";
-open( DAT, ">$data_trace" ) or die "ouverture de $data_trace : $!\n";
-autoflush DAT;
+Text::Editor::Easy::Comm::manage_debug_file( __PACKAGE__, *DBG );
 
 # Traage
 my %function = (
@@ -305,9 +245,13 @@ sub trace {
     $function{$function}->( $self, @data );
 }
 
+my $trace_print_counter;
+
 sub trace_print {
     my ( $self, $dump_hash, @param ) = @_;
 
+    print DBG "Dbut trace_print $self, $dump_hash, @param\n";
+
     #Ecriture sur fichier
     my $seek_start = tell ENC;
     no warnings;    # @param peut contenir des lment undef
@@ -317,9 +261,16 @@ sub trace_print {
     my $seek_end = tell ENC;
 
     # Traage des print
-    my %options = eval $dump_hash;
-    return if ($@);
-
+    my %options;
+    print DBG "trace_print avant eval dump\n";
+    if ( defined $dump_hash ) {
+        %options = eval $dump_hash;
+        return if ($@);
+    }
+    else {
+        return;
+    }
+    print DBG "trace_print aprs eval dump\n";
     my @calls = eval $options{'calls'};
     trace_display_calls(@calls) if ( !$@ );
     my $tid = $options{'who'};
@@ -336,7 +287,7 @@ sub trace_print {
     #        my $param = join ('', @param);
     #        use warnings;
     #        my $seek_end = tell ENC;
-    return if ( !defined $thread_ref );
+    #return if ( !defined $thread_ref );
 
     if ( my $eval_ref = $thread_ref->[EVAL] ) {
         for my $indice ( 1 .. scalar(@calls) / 3 ) {
@@ -354,31 +305,31 @@ sub trace_print {
 
     if ( defined $thread_ref->[STATUS] ) {
 
-        #print DAT "\t  Statut de $tid : ", $thread_ref->[STATUS][0] . "\n";
+        #print DBG "\t  Statut de $tid : ", $thread_ref->[STATUS][0] . "\n";
     }
-
     my $call_id_ref = $thread_ref->[CALL_ID_REF];
     my $call_id;
     if ( defined $call_id_ref ) {
         $call_id = $thread_ref->[CALL_ID];
 
-        #print DAT "\tThread liste :\n";
+        #print DBG "\tThread liste :\n";
         for my $thread_id ( sort keys %{ $call_id_ref->[THREAD_LIST] } ) {
 
-            #print DAT "\t\t$thread_id\n";
+            #print DBG "\t\t$thread_id\n";
         }
 
-        #print DAT "\tMethod liste :\n";
+        #print DBG "\tMethod liste :\n";
         for my $method ( sort keys %{ $call_id_ref->[METHOD_LIST] } ) {
 
-            #print DAT "\t\t$method\n";
+            #print DBG "\t\t$method\n";
         }
     }
 
     # Redirection ventuelle du print
+    print DBG "trace_print avant redirection\n";
     if ( my $hash_list_ref = $self->[REDIRECT] ) {
 
-   #print DAT "REDIRECTION effective pour appel ", $thread_ref->[CALL_ID], "\n";
+   #print DBG "REDIRECTION effective pour appel ", $thread_ref->[CALL_ID], "\n";
       RED: for my $redirect_ref ( values %{$hash_list_ref} ) {
 
             # Eviter l'autovivification
@@ -386,44 +337,60 @@ sub trace_print {
               if ( !defined $call_id_ref
                 and $tid != $redirect_ref->{'thread'} );
 
-#print DAT "redirect_ref thread = ", $redirect_ref->{'thread'}, " (tid = $tid)\n";
+#print DBG "redirect_ref thread = ", $redirect_ref->{'thread'}, " (tid = $tid)\n";
             if ( $tid == $redirect_ref->{'thread'}
                 or defined $call_id_ref->[THREAD_LIST]
                 { $redirect_ref->{'thread'} } )
             {
 
-                #print DAT "A ECRIRE : ", join ('', @param), "\n";
+                #print DBG "A ECRIRE : ", join ('', @param), "\n";
                 my $excluded = $redirect_ref->{'exclude'};
 
-       #print DAT "Excluded : ", $call_id_ref->[THREAD_LIST]{ $excluded }, "\n";
+       #print DBG "Excluded : ", $call_id_ref->[THREAD_LIST]{ $excluded }, "\n";
                 next RED
                   if (  defined $excluded
                     and defined $call_id_ref->[THREAD_LIST]{$excluded} );
-                Async_Editor->ask2( $redirect_ref->{'method'}, $param );
+                Text::Editor::Easy::Async->ask2( $redirect_ref->{'method'},
+                    $param );
 
 # Danger redirection synchrone devrait tre possible si le thread 0 ne fait pas partie de la liste...
-# Editor->ask2( $redirect_ref->{'method'}, join ('', @param) );
+# Text::Editor::Easy->ask2( $redirect_ref->{'method'}, join ('', @param) );
             }
 
-           #print DAT "redirect_ref method = ", $redirect_ref->{'method'}, "\n";
+           #print DBG "redirect_ref method = ", $redirect_ref->{'method'}, "\n";
         }
     }
-    if ( !defined $self->[FULL_TRACE] ) {
-        $self->[FULL_TRACE] =
-          Editor->create_standard_server_thread( "Easy::Trace::Print",
-            [ 'trace_full', 'init_trace_print', 'get_info_for_display' ], [] );
-        Async_Editor->init_trace_print($own_STDOUT);
-    }
-    Async_Editor->trace_full( $seek_start, $seek_end, $tid, $call_id,
-        $options{'calls'}, $param );
 
-    return;    # Eviter autre chose que le context void pour Async_Editor
+    if ( !$self->[FULL_TRACE] ) {
+        $self->[FULL_TRACE] = 1;
+        Text::Editor::Easy->create_new_server(
+            {
+                'use'     => 'Text::Editor::Easy::Trace::Print',
+                'package' => "Text::Editor::Easy::Trace::Print",
+                'methods' => [ 'trace_full', 'get_info_for_display' ],
+                'object'  => [],
+                'init'    => [
+                    'Text::Editor::Easy::Trace::Print::init_trace_print',
+                    $own_STDOUT
+                ],
+            }
+        );
+    }
+    Text::Editor::Easy::Async->trace_full( $seek_start, $seek_end, $tid,
+        $call_id, $options{'calls'}, $param );
+    print DBG "Fin trace_print $self\n";
+    return
+      ;  # Eviter autre chose que le context void pour Text::Editor::Easy::Async
 }
 
 sub reference_print_redirection {
     my ( $self, $hash_ref ) = @_;
 
+    if ( !defined $self->[COUNTER] ) {
+        $self->[COUNTER] = 0;
+    }
     my $counter = $self->[COUNTER] + 1;
+
     $self->[REDIRECT]{$counter} = $hash_ref;
     $self->[COUNTER] = $counter;
     return $counter;
@@ -438,7 +405,7 @@ sub trace_call {
 
     $self->[TOTAL][CALLS] += 1;
 
-    #print DAT "C|$call_id|$server|$seconds|$micro|$method\n";
+    print DBG "C|$call_id|$server|$seconds|$micro|$method\n";
 
     my ( $client, $id ) = split( /_/, $call_id );
     my $thread_ref  = $self->[THREAD][$client];
@@ -457,10 +424,10 @@ sub trace_call {
     # Le thread client est peut-tre dj au service d'un call...
     if ( $call_id_ref->[SYNC] ) {
 
-        #print DAT "$call_id synchrone ($context)\n";
+        #print DBG "$call_id synchrone ($context)\n";
         if ( my $previous_call_id_ref = $thread_ref->[CALL_ID_REF] ) {
 
-#print DAT "Pour $call_id, rcupration d'lments de ", $thread_ref->[CALL_ID], "\n";
+#print DBG "Pour $call_id, rcupration d'lments de ", $thread_ref->[CALL_ID], "\n";
 #$call_id_ref->[PREVIOUS] = $previous_call_id_ref;
 
             # Copies des valeurs, nouvelle rfrences
@@ -471,11 +438,11 @@ sub trace_call {
             %{ $call_id_ref->[INSTANCE_LIST] } =
               %{ $previous_call_id_ref->[INSTANCE_LIST] };
 
-#print DAT "Thread liste pour $call_id futur : ", keys %{$call_id_ref->[THREAD_LIST]}, "\n";
+#print DBG "Thread liste pour $call_id futur : ", keys %{$call_id_ref->[THREAD_LIST]}, "\n";
         }
         else {
 
-            #print DAT "Pour $call_id, pas de rcupration d'lments\n";
+            #print DBG "Pour $call_id, pas de rcupration d'lments\n";
             $call_id_ref->[THREAD_LIST]{$client} = 1;
         }
     }
@@ -484,11 +451,11 @@ sub trace_call {
         $call_id_ref->[THREAD_LIST] = {};
     }
 
-    #print DAT "THREAD_LIST de $call_id aprs CALL contexte $context :\n";
+    #print DBG "THREAD_LIST de $call_id aprs CALL contexte $context :\n";
     #for ( sort keys %{$call_id_ref->[THREAD_LIST]} ) {
-    #        print DAT "$_ ";
+    #        print DBG "$_ ";
     #}
-    #print DAT "\n";
+    #print DBG "\n";
     $call_id_ref->[METHOD_LIST]{$method}       = 1;
     $call_id_ref->[INSTANCE_LIST]{$unique_ref} = 1;
     $call_id_ref->[METHOD]                     = $method;
@@ -498,7 +465,7 @@ sub trace_call {
     if ( defined $thread_status and $thread_status =~ /^P/ ) {
 
         # deadlock possible
-        print DAT
+        print DBG
 "DANGER client '$client' asking '$method' to server '$server', already pending : $thread_status\n";
     }
     $call_id_ref->[STATUS] = 'not yet started';
@@ -512,7 +479,7 @@ sub trace_call {
 sub trace_new {
     my ( $self, $from, $dump_array ) = @_;
 
-    #print DAT "N:$from\n";
+    #print DBG "N:$from\n";
     my @calls = eval $dump_array;
     trace_display_calls(@calls) if ( !$@ );
 }
@@ -521,7 +488,10 @@ sub trace_response {
     my ( $self, $from, $call_id, $method, $seconds, $micro, $response ) = @_;
 
     my $call_id_ref = $self->[CALL]{$call_id};
-    return if ( !defined $call_id_ref );
+    return
+      if ( !defined $call_id_ref )
+      ;    # Cela arrive pour les mthodes d'initialisation de thread
+     # ==> tant qu'elles ne sont pas appeles de faon standard (avec traage du call)
 
     $self->[TOTAL][RESPONSES] += 1;
 
@@ -531,8 +501,10 @@ sub trace_response {
         $self->[RESPONSE]{$call_id} = $response;
     }
 
-    #print DAT "R|$from|$call_id|$seconds|$micro|$method\n$response\n";
+    #print DBG "R|$from|$call_id|$seconds|$micro|$method\n$response\n";
 
+# Ne faudrait-il pas faire plutot un shift de "$self->[THREAD][$from][STATUS]" ?
+# ==> permettre de tracer des requtes interruptibles tout en traant les requtes internes
     $self->[THREAD][$from] = ();
     $self->[THREAD][$from][STATUS][0] = "idle|$call_id";
 
@@ -558,13 +530,13 @@ sub trace_response {
     my $call_id_client_ref = $self->[THREAD][$client][CALL_ID_REF];
 
 #if ( defined $call_id_client_ref ) {
-#        print DAT "Liste de threads avant mnage pour l'appelant (", $self->[THREAD][$client][CALL_ID], ")\n";
+#        print DBG "Liste de threads avant mnage pour l'appelant (", $self->[THREAD][$client][CALL_ID], ")\n";
 #        for ( sort keys %{$call_id_client_ref->[THREAD_LIST]} ) {
-#            print DAT "$_ ";
+#            print DBG "$_ ";
 #        }
-#        print DAT "\n";
+#        print DBG "\n";
 #}
-#print DAT "Mise  zro de la THREAD_LIST pour $call_id\n";
+#print DBG "Mise  zro de la THREAD_LIST pour $call_id\n";
 
  # Mnage de CALL et RESPONSE (sauf si asynchrone avec rcupration identifiant)
     if ( $call_id_ref->[SYNC] or $call_id_ref->[CONTEXT] eq 'AV' )
@@ -582,22 +554,28 @@ sub trace_response {
     $call_id_client_ref = $self->[THREAD][$client][CALL_ID_REF];
 
 #if ( defined $call_id_client_ref ) {
-#        print DAT "Liste de threads restant pour l'appelant (", $self->[THREAD][$client][CALL_ID], ")\n";
+#        print DBG "Liste de threads restant pour l'appelant (", $self->[THREAD][$client][CALL_ID], ")\n";
 #        for ( sort keys %{$call_id_client_ref->[THREAD_LIST]} ) {
-#            print DAT "$_ ";
+#            print DBG "$_ ";
 #        }
-#        print DAT "\n";
+#        print DBG "\n";
+#}
+#if ( my $call_id_ref = $self->[CALL]{$call_id} ) {
+#    print DBG "Status de call_id $call_id : ", $call_id_ref->[STATUS], "\n";
+#}
+#else {
+#	print DBG "$call_id plus dfini...\n";
 #}
 }
 
 sub free_call_id {
     my ( $self, $call_id ) = @_;
 
-    #print DAT "Dans free_call_id A librer : $call_id\n";
+    #print DBG "Dans free_call_id A librer : $call_id\n";
 
     my $call_id_ref = $self->[CALL]{$call_id};
 
-    #print DAT "   Context $call_id_ref->[CONTEXT]\n";
+    #print DBG "   Context $call_id_ref->[CONTEXT]\n";
 
     %{ $call_id_ref->[THREAD_LIST] }   = ();
     %{ $call_id_ref->[METHOD_LIST] }   = ();
@@ -623,16 +601,16 @@ sub trace_start {
 
     $call_id_ref->[STATUS] = 'started';
 
-    #print DAT "S|$who|$call_id|$seconds|$micro|$method\n";
+    #print DBG "S|$who|$call_id|$seconds|$micro|$method\n";
 
     $call_id_ref->[THREAD_LIST]{$who} = 1;
 
-    #print DAT "Ajout de $who pour la THREAD_LIST de $call_id\n\t";
-    #print DAT "$call_id_ref ";
+    #print DBG "Ajout de $who pour la THREAD_LIST de $call_id\n\t";
+    #print DBG "$call_id_ref ";
     #for ( sort keys %{$call_id_ref->[THREAD_LIST]} ) {
-    #        print DAT "$_ ";
+    #        print DBG "$_ ";
     #}
-    #print DAT "\n";
+    #print DBG "\n";
 
     $call_id_ref->[THREAD]{$who} = 1;
     $self->[CALL]{$call_id}      = $call_id_ref;
@@ -646,11 +624,11 @@ sub trace_start {
     #my @imbriqued_calls = keys %{ $call_id_ref->[THREAD_LIST] };
     #if ( scalar @imbriqued_calls > 2 ) {
     #        for my $thread_id ( sort @imbriqued_calls ) {
-    #print DAT "\tS!!! $thread_id|";
+    #print DBG "\tS!!! $thread_id|";
     #            for my $status ( @{ $self->[THREAD][$thread_id][STATUS] } ) {
-    #print DAT " $status,";
+    #print DBG " $status,";
     #            }
-    #print DAT "\n";
+    #print DBG "\n";
     #        }
     #}
     # Vrification de la thread liste de l'appelant si synchrone  (debuggage)
@@ -659,12 +637,12 @@ sub trace_start {
         my $thread_ref = $self->[THREAD][$client];
 
         #if ( defined $thread_ref and defined $thread_ref->[CALL_ID] ) {
-        #print DAT "THREAD_LIST de l'appelant $thread_ref->[CALL_ID] :\n\t";
+        #print DBG "THREAD_LIST de l'appelant $thread_ref->[CALL_ID] :\n\t";
         #my $call_client_ref = $thread_ref->[CALL_ID_REF];
         #for ( sort keys %{$call_client_ref->[THREAD_LIST]} ) {
-        #    print DAT "$_ ";
+        #    print DBG "$_ ";
         #}
-        #print DAT "\n";
+        #print DBG "\n";
         #}
     }
 }
@@ -674,13 +652,15 @@ sub trace_display_calls {
     return;
     for my $indice ( 1 .. scalar(@calls) / 3 ) {
         my ( $pack, $file, $line ) = splice @calls, 0, 3;
-        print DAT "\tF|$file|L|$line|P|$pack\n";
+        print DBG "\tF|$file|L|$line|P|$pack\n";
     }
 }
 
 sub async_status {
     my ( $self, $call_id ) = @_;
 
+#print "Dans async_status $self|$call_id|", $self->[CALL]{$call_id}[STATUS], "\n";
+#print DBG "Dans async_status $self|$call_id|", $self->[CALL]{$call_id}[STATUS], "\n";
     return $self->[CALL]{$call_id}[STATUS];
 }
 
@@ -715,10 +695,10 @@ sub size_self_data {
     print "   CALL     : ", total_size( $self->[CALL] ),   "\n";
     my @array = %{ $self->[CALL] };
     print "Nombre de cl x 2 : ", scalar(@array), "\n";
-    print DAT "Nombre de cl x 2 : ", scalar(@array), "\n";
+    print DBG "Nombre de cl x 2 : ", scalar(@array), "\n";
     my $hash_ref = $self->[CALL];
     for ( sort keys %{ $self->[CALL] } ) {
-        print DAT "\t$_|", $hash_ref->{$_}[CONTEXT], "|",
+        print DBG "\t$_|", $hash_ref->{$_}[CONTEXT], "|",
           $hash_ref->{$_}[METHOD], "\n";
     }
     print "   RESPONSE : ", total_size( $self->[RESPONSE] ), "\n";
@@ -758,12 +738,17 @@ sub data_substitute_eval_with_file {
     my ( $self, $file, $number ) = @_;
 
     # Rcupration du thread ayant appel cette procdure
+    print DBG "Dans data_substitute_eval_with_file : $self|$file|$number\n";
     my $call_id = $self->[THREAD][ threads->tid ][CALL_ID];
-    my ($calling_thread) = split( /_/, $call_id );
-
-    #print "Calling thread : $calling_thread\n";
-
-    $self->[THREAD][$calling_thread][EVAL] = [ $file, $number ];
+    print DBG
+      "Dans data_substitute_eval_with_file : aprs rcupration de call_id\n";
+    my $calling_thread;
+    if ( defined $call_id ) {
+        print DBG "Call_id : $call_id\n";
+        ($calling_thread) = split( /_/, $call_id );
+        print DBG "Calling thread : $calling_thread\n";
+        $self->[THREAD][$calling_thread][EVAL] = [ $file, $number ];
+    }
 }
 
 sub reference_zone {
@@ -786,4 +771,70 @@ sub zone_list {
     return keys %{ $self->[ZONE] };
 }
 
+=head1 FUNCTIONS
+
+=head2 async_response
+
+=head2 async_status
+
+=head2 data_file_name
+
+=head2 data_get_editor_from_file_name
+
+=head2 data_get_editor_from_name
+
+=head2 data_name
+
+=head2 data_substitute_eval_with_file
+
+=head2 file_name_of_zone_order
+
+=head2 find_in_zone
+
+=head2 free_call_id
+
+=head2 init_data
+
+=head2 list_in_zone
+
+=head2 name_of_zone_order
+
+=head2 print_thread_list
+
+=head2 reference_editor
+
+=head2 reference_print_redirection
+
+=head2 reference_zone
+
+=head2 size_self_data
+
+=head2 trace
+
+=head2 trace_call
+
+=head2 trace_display_calls
+
+=head2 trace_new
+
+=head2 trace_print
+
+=head2 trace_response
+
+=head2 trace_start
+
+=head2 zone_list
+
+=head2 zone_named
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 Sebastien Grommier, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+
+=cut
+
 1;
